@@ -2,12 +2,12 @@
    +----------------------------------------------------------------------+
    | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2003 The PHP Group                                |
+   | Copyright (c) 1997-2008 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
@@ -17,7 +17,7 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: tsrm_virtual_cwd.c,v 1.41.2.8 2004/12/02 01:04:46 sesser Exp $ */
+/* $Id: tsrm_virtual_cwd.c,v 1.41.2.11.2.6 2007/12/31 07:22:45 sebastian Exp $ */
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -37,8 +37,7 @@
 #endif
 
 #ifdef NETWARE
-/*#include "pipe.h"*/
-#include "tsrm_nw.h"
+#include <fsio.h>
 #endif
 
 #ifndef HAVE_REALPATH
@@ -137,15 +136,9 @@ static int php_check_dots(const char *element, int n)
 	
 static int php_is_dir_ok(const cwd_state *state) 
 {
-#if !(defined(NETWARE) && defined(CLIB_STAT_PATCH))
 	struct stat buf;
 
 	if (stat(state->cwd, &buf) == 0 && S_ISDIR(buf.st_mode))
-#else
-    struct stat_libc buf;
-
-    if (stat(state->cwd, (struct stat*)(&buf)) == 0 && S_ISDIR(buf.st_mode))
-#endif
 		return (0);
 
 	return (1);
@@ -153,15 +146,9 @@ static int php_is_dir_ok(const cwd_state *state)
 
 static int php_is_file_ok(const cwd_state *state) 
 {
-#if !(defined(NETWARE) && defined(CLIB_STAT_PATCH))
 	struct stat buf;
 
 	if (stat(state->cwd, &buf) == 0 && S_ISREG(buf.st_mode))
-#else
-    struct stat_libc buf;
-
-    if (stat(state->cwd, (struct stat*)(&buf)) == 0 && S_ISREG(buf.st_mode))
-#endif
 		return (0);
 
 	return (1);
@@ -196,8 +183,20 @@ CWD_API void virtual_cwd_startup(void)
 {
 	char cwd[MAXPATHLEN];
 	char *result;
-
-	result = getcwd(cwd, sizeof(cwd));	
+#ifdef NETWARE
+	result = getcwdpath(cwd, NULL, 1);
+	if(result)
+	{
+		char *c=cwd;
+		while(c = strchr(c, '\\'))
+		{
+			*c='/';
+			++c;
+		}
+	}
+#else
+	result = getcwd(cwd, sizeof(cwd));
+#endif
 	if (!result) {
 		cwd[0] = '\0';
 	}
@@ -210,7 +209,7 @@ CWD_API void virtual_cwd_startup(void)
 	cwd_globals_ctor(&cwd_globals TSRMLS_CC);
 #endif
 
-#if defined(TSRM_WIN32) && defined(ZTS)
+#if (defined(TSRM_WIN32) || defined(NETWARE)) && defined(ZTS)
 	cwd_mutex = tsrm_mutex_alloc();
 #endif
 }
@@ -220,7 +219,7 @@ CWD_API void virtual_cwd_shutdown(void)
 #ifndef ZTS
 	cwd_globals_dtor(&cwd_globals TSRMLS_CC);
 #endif
-#if defined(TSRM_WIN32) && defined(ZTS)
+#if (defined(TSRM_WIN32) || defined(NETWARE)) && defined(ZTS)
 	tsrm_mutex_free(cwd_mutex);
 #endif
 
@@ -418,8 +417,20 @@ CWD_API int virtual_file_ex(cwd_state *state, const char *path, verify_path_func
 					state->cwd[state->cwd_length++] = DEFAULT_SLASH;
 				}
 #elif defined(NETWARE)
-				/* If the token is a volume name, it will have colon at the end -- so, no slash before it */
-				if (ptr[ptr_length-1] != ':') {
+				/* 
+					Below code keeps appending to state->cwd a File system seperator
+					cases where this appending should not happen is given below,
+					a) sys: should just be left as it is
+					b) sys:system should just be left as it is,
+					Colon is allowed only in the first token as volume names alone can have the : in their names.
+					Files and Directories cannot have : in their names
+					So the check goes like this,
+					For second token and above simply append the DEFAULT_SLASH to the state->cwd.
+					For first token check for the existence of : 
+					if it exists don't append the DEFAULT_SLASH to the state->cwd.
+				*/
+				if(((state->cwd_length == 0) && (strchr(ptr, ':') == NULL)) || (state->cwd_length > 0))
+				{
 					state->cwd[state->cwd_length++] = DEFAULT_SLASH;
 				}
 #else
@@ -683,37 +694,23 @@ CWD_API int virtual_rename(char *oldname, char *newname TSRMLS_DC)
 	return retval;
 }
 
-#if !(defined(NETWARE) && defined(CLIB_STAT_PATCH))
 CWD_API int virtual_stat(const char *path, struct stat *buf TSRMLS_DC)
 {
 	cwd_state new_state;
 	int retval;
 
 	CWD_STATE_COPY(&new_state, &CWDG(cwd));
-	virtual_file_ex(&new_state, path, NULL, 1);
+	if (virtual_file_ex(&new_state, path, NULL, 1)) {
+		return -1;
+	}
 
 	retval = stat(new_state.cwd, buf);
 
 	CWD_STATE_FREE(&new_state);
 	return retval;
 }
-#else
-CWD_API int virtual_stat(const char *path, struct stat_libc *buf TSRMLS_DC)
-{
-	cwd_state new_state;
-	int retval;
 
-	CWD_STATE_COPY(&new_state, &CWDG(cwd));
-	virtual_file_ex(&new_state, path, NULL, 1);
-
-	retval = stat(new_state.cwd, (struct stat*)buf);
-
-	CWD_STATE_FREE(&new_state);
-	return retval;
-}
-#endif
-
-#if !defined(TSRM_WIN32) && !defined(NETWARE)
+#ifndef TSRM_WIN32
 CWD_API int virtual_lstat(const char *path, struct stat *buf TSRMLS_DC)
 {
 	cwd_state new_state;
@@ -852,7 +849,7 @@ CWD_API FILE *virtual_popen(const char *command, const char *type TSRMLS_DC)
 	dir_length = CWDG(cwd).cwd_length;
 	dir = CWDG(cwd).cwd;
 
-	ptr = command_line = (char *) malloc(command_length + sizeof("cd '' ; ") + dir_length +1+1);
+	ptr = command_line = (char *) malloc(command_length + sizeof("cd '' ; ") + dir_length +extra+1+1);
 	if (!command_line) {
 		return NULL;
 	}
