@@ -2,12 +2,12 @@
    +----------------------------------------------------------------------+
    | Zend Engine                                                          |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1998-2001 Zend Technologies Ltd. (http://www.zend.com) |
+   | Copyright (c) 1998-2003 Zend Technologies Ltd. (http://www.zend.com) |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 0.92 of the Zend license,     |
+   | This source file is subject to version 2.00 of the Zend license,     |
    | that is bundled with this package in the file LICENSE, and is        | 
-   | available at through the world-wide-web at                           |
-   | http://www.zend.com/license/0_92.txt.                                |
+   | available through the world-wide-web at the following url:           |
+   | http://www.zend.com/license/2_00.txt.                                |
    | If you did not receive a copy of the Zend license and are unable to  |
    | obtain it through the world-wide-web, please send a note to          |
    | license@zend.com so we can mail you a copy immediately.              |
@@ -27,8 +27,7 @@
 
 void free_zend_constant(zend_constant *c)
 {
-	if (!(c->flags & CONST_PERSISTENT)
-		|| (c->flags & CONST_EFREE_PERSISTENT)) {
+	if (!(c->flags & CONST_PERSISTENT)) {
 		zval_dtor(&c->value);
 	}
 	free(c->name);
@@ -40,9 +39,6 @@ void copy_zend_constant(zend_constant *c)
 	c->name = zend_strndup(c->name, c->name_len);
 	if (!(c->flags & CONST_PERSISTENT)) {
 		zval_copy_ctor(&c->value);
-		if (c->flags & CONST_EFREE_PERSISTENT) { /* persist_alloc()'d data */
-			persist_alloc(&c->value);
-		}
 	}
 }
 
@@ -220,48 +216,63 @@ ZEND_API void zend_register_string_constant(char *name, uint name_len, char *str
 ZEND_API int zend_get_constant(char *name, uint name_len, zval *result TSRMLS_DC)
 {
 	zend_constant *c;
-	char *lookup_name = estrndup(name, name_len);
-	int retval;
+	char *lookup_name;
+	int retval = 1;
 
-	zend_str_tolower(lookup_name, name_len);
+	if (zend_hash_find(EG(zend_constants), name, name_len+1, (void **) &c) == FAILURE) {
+		lookup_name = estrndup(name, name_len);
+		zend_str_tolower(lookup_name, name_len);
 
-	if (zend_hash_find(EG(zend_constants), lookup_name, name_len+1, (void **) &c)==SUCCESS) {
-		if ((c->flags & CONST_CS) && memcmp(c->name, name, name_len)!=0) {
-			retval=0;
+		if (zend_hash_find(EG(zend_constants), lookup_name, name_len+1, (void **) &c)==SUCCESS) {
+			if ((c->flags & CONST_CS) && memcmp(c->name, name, name_len)!=0) {
+				retval=0;
+			}
 		} else {
-			retval=1;
-			*result = c->value;
-			zval_copy_ctor(result);
+			retval=0;
 		}
-	} else {
-		retval=0;
+		efree(lookup_name);
 	}
-	
-	efree(lookup_name);
+
+	if (retval) {
+		*result = c->value;
+		zval_copy_ctor(result);
+		result->is_ref = 0;
+		result->refcount = 1;
+	}
+
 	return retval;
 }
 
 
 ZEND_API int zend_register_constant(zend_constant *c TSRMLS_DC)
 {
-	char *lowercase_name = zend_strndup(c->name, c->name_len);
+	char *lowercase_name = NULL;
+	char *name;
 	int ret = SUCCESS;
 
 #if 0
 	printf("Registering constant for module %d\n", c->module_number);
 #endif
 
-	zend_str_tolower(lowercase_name, c->name_len);
-	if (zend_hash_add(EG(zend_constants), lowercase_name, c->name_len, (void *) c, sizeof(zend_constant), NULL)==FAILURE) {
+	if (!(c->flags & CONST_CS)) {
+		lowercase_name = estrndup(c->name, c->name_len);
+		zend_str_tolower(lowercase_name, c->name_len);
+		name = lowercase_name;
+	} else {
+		name = c->name;
+	}
+
+	if (zend_hash_add(EG(zend_constants), name, c->name_len, (void *) c, sizeof(zend_constant), NULL)==FAILURE) {
+		zend_error(E_NOTICE,"Constant %s already defined", name);
 		free(c->name);
-		if (!(c->flags & CONST_PERSISTENT)
-			|| (c->flags & CONST_EFREE_PERSISTENT)) {
+		if (!(c->flags & CONST_PERSISTENT)) {
 			zval_dtor(&c->value);
 		}
-		zend_error(E_NOTICE,"Constant %s already defined", lowercase_name);
 		ret = FAILURE;
 	}
-	free(lowercase_name);
+	if (lowercase_name) {
+		efree(lowercase_name);
+	}
 	return ret;
 }
 
