@@ -1,29 +1,38 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP version 4.0                                                      |
+   | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2001 The PHP Group                                |
+   | Copyright (c) 1997-2008 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
    +----------------------------------------------------------------------+
-   | Authors: Sascha Schumann <sascha@schumann.cx>                        |
+   | Author: Sascha Schumann <sascha@schumann.cx>                         |
    +----------------------------------------------------------------------+
  */
 
-/* $Id: dba_dbm.c,v 1.10 2001/08/05 01:42:34 zeev Exp $ */
+/* $Id: dba_dbm.c,v 1.22.2.4.8.3 2007/12/31 07:22:46 sebastian Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include "php.h"
 
 #if DBA_DBM
 #include "php_dbm.h"
 
-#include <dbm.h>
+#ifdef DBM_INCLUDE_FILE
+#include DBM_INCLUDE_FILE
+#endif
+#if DBA_GDBM
+#include "php_gdbm.h"
+#endif
 
 #include <unistd.h>
 #include <sys/types.h>
@@ -52,7 +61,7 @@ DBA_OPEN_FUNC(dbm)
 
 	if(info->argc > 0) {
 		convert_to_long_ex(info->argv[0]);
-		filemode = (*info->argv[0])->value.lval;
+		filemode = Z_LVAL_PP(info->argv[0]);
 	}
 	
 	if(info->mode == DBA_TRUNC) {
@@ -74,13 +83,14 @@ DBA_OPEN_FUNC(dbm)
 		return FAILURE;
 	}
 
-	info->dbf = calloc(sizeof(dba_dbm_data), 1);
+	info->dbf = pemalloc(sizeof(dba_dbm_data), info->flags&DBA_PERSISTENT);
+	memset(info->dbf, 0, sizeof(dba_dbm_data));
 	return SUCCESS;
 }
 
 DBA_CLOSE_FUNC(dbm)
 {
-	free(info->dbf);
+	pefree(info->dbf, info->flags&DBA_PERSISTENT);
 	dbmclose();
 }
 
@@ -103,6 +113,14 @@ DBA_UPDATE_FUNC(dbm)
 	datum gval;
 
 	DBM_GKEY;
+
+	if (mode == 1) { /* insert */
+		gval = fetch(gkey);
+		if(gval.dptr) {
+			return FAILURE;
+		}
+	}
+
 	gval.dptr = (char *) val;
 	gval.dsize = vallen;
 	
@@ -172,6 +190,17 @@ DBA_SYNC_FUNC(dbm)
 	return SUCCESS;
 }
 
+DBA_INFO_FUNC(dbm)
+{
+#if DBA_GDBM
+	if (!strcmp(DBM_VERSION, "GDBM"))
+	{
+		return dba_info_gdbm(hnd, info TSRMLS_CC);
+	}
+#endif
+	return estrdup(DBM_VERSION);
+}
+
 #endif
 
 /*
@@ -179,6 +208,6 @@ DBA_SYNC_FUNC(dbm)
  * tab-width: 4
  * c-basic-offset: 4
  * End:
- * vim600: sw=4 ts=4 tw=78 fdm=marker
- * vim<600: sw=4 ts=4 tw=78
+ * vim600: sw=4 ts=4 fdm=marker
+ * vim<600: sw=4 ts=4
  */
