@@ -1,22 +1,22 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP version 4.0                                                      |
+   | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2001 The PHP Group                                |
+   | Copyright (c) 1997-2008 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
    +----------------------------------------------------------------------+
-   | Authors: Thies C. Arntzen (thies@thieso.net)                         |
+   | Author: Thies C. Arntzen <thies@thieso.net>                          |
    +----------------------------------------------------------------------+
  */
 
-/* $Id: iptc.c,v 1.33 2001/08/11 17:03:37 zeev Exp $ */
+/* $Id: iptc.c,v 1.41.4.5.2.3 2007/12/31 07:22:52 sebastian Exp $ */
 
 /*
  * Functions to parse & compse IPTC data.
@@ -112,9 +112,7 @@ static int php_iptc_get1(FILE *fp, int spool, unsigned char **spoolbuf TSRMLS_DC
  */
 static int php_iptc_read_remaining(FILE *fp, int spool, unsigned char **spoolbuf TSRMLS_DC)
 {
- 	int c;
-
-  	while ((c = php_iptc_get1(fp, spool, spoolbuf TSRMLS_CC)) != EOF) continue;
+  	while (php_iptc_get1(fp, spool, spoolbuf TSRMLS_CC) != EOF) continue;
 
 	return M_EOI;
 }
@@ -194,7 +192,7 @@ PHP_FUNCTION(iptcembed)
         convert_to_string_ex(iptcdata);
         convert_to_string_ex(jpeg_file);
         convert_to_long_ex(spool_flag);
-		spool = (*spool_flag)->value.lval;
+		spool = Z_LVAL_PP(spool_flag);
         break;
 
     case 2:
@@ -210,16 +208,20 @@ PHP_FUNCTION(iptcembed)
         break;
     }
 
-    if (php_check_open_basedir((*jpeg_file)->value.str.val TSRMLS_CC)) {
+    if (PG(safe_mode) && (!php_checkuid(Z_STRVAL_PP(jpeg_file), NULL, CHECKUID_CHECK_FILE_AND_DIR))) {
 		RETURN_FALSE;
 	}
 
-    if ((fp = VCWD_FOPEN((*jpeg_file)->value.str.val, "rb")) == 0) {
-        php_error(E_WARNING, "Unable to open %s", (*jpeg_file)->value.str.val);
+    if (php_check_open_basedir(Z_STRVAL_PP(jpeg_file) TSRMLS_CC)) {
+		RETURN_FALSE;
+	}
+
+    if ((fp = VCWD_FOPEN(Z_STRVAL_PP(jpeg_file), "rb")) == 0) {
+        php_error_docref(NULL TSRMLS_CC, E_WARNING, "Unable to open %s", Z_STRVAL_PP(jpeg_file));
         RETURN_FALSE;
     }
 
-	len = (*iptcdata)->value.str.len;
+	len = Z_STRLEN_PP(iptcdata);
 
 	if (spool < 2) {
 		fstat(fileno(fp), &sb);
@@ -275,7 +277,7 @@ PHP_FUNCTION(iptcembed)
 				php_iptc_put1(fp, spool, (unsigned char)(len&0xff), poi?&poi:0 TSRMLS_CC);
 					
 				for (inx = 0; inx < len; inx++)
-					php_iptc_put1(fp, spool, (*iptcdata)->value.str.val[inx], poi?&poi:0 TSRMLS_CC);
+					php_iptc_put1(fp, spool, Z_STRVAL_PP(iptcdata)[inx], poi?&poi:0 TSRMLS_CC);
 				break;
 
 			case M_SOS:								
@@ -304,7 +306,7 @@ PHP_FUNCTION(iptcembed)
    Parse binary IPTC-data into associative array */
 PHP_FUNCTION(iptcparse)
 {
-	unsigned int length, inx, len, inheader, tagsfound;
+	unsigned int length, inx, len, tagsfound;
 	unsigned char *buffer;
 	unsigned char recnum, dataset;
 	unsigned char key[ 16 ];
@@ -316,14 +318,13 @@ PHP_FUNCTION(iptcparse)
 	convert_to_string_ex(str);
 
 	inx = 0;
-	length = (*str)->value.str.len;
-	buffer = (*str)->value.str.val;
+	length = Z_STRLEN_PP(str);
+	buffer = Z_STRVAL_PP(str);
 
-	inheader = 0; /* have we already found the IPTC-Header??? */
 	tagsfound = 0; /* number of tags already found */
 
 	while (inx < length) { /* find 1st tag */
-		if ((buffer[inx] == 0x1c) && (buffer[inx+1] == 0x02)){ 
+		if ((buffer[inx] == 0x1c) && ((buffer[inx+1] == 0x01) || (buffer[inx+1] == 0x02))){
 			break;
 		} else {
 			inx++;
@@ -350,27 +351,21 @@ PHP_FUNCTION(iptcparse)
 			inx += 2;
 		}
 
-		sprintf(key, "%d#%03d", (unsigned int) dataset, (unsigned int) recnum);
+		snprintf(key, sizeof(key), "%d#%03d", (unsigned int) dataset, (unsigned int) recnum);
 
 		if ((len > length) || (inx + len) > length)
 			break;
 
 		if (tagsfound == 0) { /* found the 1st tag - initialize the return array */
-			if (array_init(return_value) == FAILURE) {
-				php_error(E_ERROR, "Unable to initialize array");
-				RETURN_FALSE;
-	  		}
+			array_init(return_value);
 		}
 
-		if (zend_hash_find(return_value->value.ht, key, strlen(key) + 1, (void **) &element) == FAILURE) {
+		if (zend_hash_find(Z_ARRVAL_P(return_value), key, strlen(key) + 1, (void **) &element) == FAILURE) {
 			ALLOC_ZVAL(values);
 			INIT_PZVAL(values);
-			if (array_init(values) == FAILURE) {
-				php_error(E_ERROR, "Unable to initialize array");
-				RETURN_FALSE;
-			}
+			array_init(values);
 			
-			zend_hash_update(return_value->value.ht, key, strlen(key)+1, (void *) &values, sizeof(pval*), (void **) &element);
+			zend_hash_update(Z_ARRVAL_P(return_value), key, strlen(key)+1, (void *) &values, sizeof(pval*), (void **) &element);
 		} 
 			
 		add_next_index_stringl(*element, buffer+inx, len, 1);
@@ -391,6 +386,6 @@ PHP_FUNCTION(iptcparse)
  * tab-width: 4
  * c-basic-offset: 4
  * End:
- * vim600: sw=4 ts=4 tw=78 fdm=marker
- * vim<600: sw=4 ts=4 tw=78
+ * vim600: sw=4 ts=4 fdm=marker
+ * vim<600: sw=4 ts=4
  */
