@@ -38,7 +38,7 @@
 
 #if 0
 static char const *version UNUSED =
-    "$Id: strnatcmp.c,v 1.8.4.1 2003/04/16 21:11:04 moriyoshi Exp $";
+    "$Id: strnatcmp.c,v 1.8.4.2 2004/07/15 01:46:27 iliaa Exp $";
 #endif
 /* {{{ compare_right
  */
@@ -153,13 +153,13 @@ PHPAPI int strnatcmp_ex(char const *a, size_t a_len, char const *b, size_t b_len
 			return +1;
 
 		++ap; ++bp;
-		if (ap == aend && bp == bend)
+		if (ap >= aend && bp >= bend)
 			/* The strings compare the same.  Perhaps the caller
 			   will want to call strcmp to break the tie. */
 			return 0;
-		else if (ap == aend)
+		else if (ap >= aend)
 			return -1;
-		else if (bp == bend)
+		else if (bp >= bend)
 			return 1;
 	}
 }
