@@ -1,22 +1,22 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP version 4.0                                                      |
+   | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2001 The PHP Group                                |
+   | Copyright (c) 1997-2008 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
    +----------------------------------------------------------------------+
-   | Authors: Stig Sther Bakken <ssb@fast.no>                            |
+   | Author: Stig Sther Bakken <ssb@fast.no>                             |
    +----------------------------------------------------------------------+
  */
 
-/* $Id: syslog.c,v 1.32 2001/08/11 17:03:37 zeev Exp $ */
+/* $Id: syslog.c,v 1.40.4.2.2.3 2007/12/31 07:22:53 sebastian Exp $ */
 
 #include "php.h"
 
@@ -119,6 +119,9 @@ PHP_RSHUTDOWN_FUNCTION(syslog)
 	if (BG(syslog_device)) {
 		efree(BG(syslog_device));
 	}
+#ifdef PHP_WIN32
+	closelog();
+#endif
 	return SUCCESS;
 }
 
@@ -191,13 +194,18 @@ static void start_syslog(TSRMLS_D)
    Initializes all syslog-related variables */
 PHP_FUNCTION(define_syslog_variables)
 {
+	if (ZEND_NUM_ARGS() != 0) {
+		php_error_docref(NULL TSRMLS_CC, E_WARNING, "expects no parameters, %d given", ZEND_NUM_ARGS());
+		return;
+	}
+
 	if (!BG(syslog_started)) {
 		start_syslog(TSRMLS_C);
 	}
 }
 /* }}} */
 
-/* {{{ proto int openlog(string ident, int option, int facility)
+/* {{{ proto bool openlog(string ident, int option, int facility)
    Open connection to system logger */
 /*
    ** OpenLog("nettopp", $LOG_PID, $LOG_LOCAL1);
@@ -206,27 +214,32 @@ PHP_FUNCTION(define_syslog_variables)
  */
 PHP_FUNCTION(openlog)
 {
-	pval **ident, **option, **facility;
+	char *ident;
+	long option, facility;
+	int ident_len;
 
-	if (ZEND_NUM_ARGS() != 3 || zend_get_parameters_ex(3, &ident, &option, &facility) == FAILURE) {
-		WRONG_PARAM_COUNT;
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "sll", &ident,
+							  &ident_len, &option, &facility) == FAILURE) {
+		return;
 	}
-	convert_to_string_ex(ident);
-	convert_to_long_ex(option);
-	convert_to_long_ex(facility);
 	if (BG(syslog_device)) {
 		efree(BG(syslog_device));
 	}
-	BG(syslog_device) = estrndup((*ident)->value.str.val, (*ident)->value.str.len);
-	openlog(BG(syslog_device), (*option)->value.lval, (*facility)->value.lval);
+	BG(syslog_device) = estrndup(ident, ident_len);
+	openlog(BG(syslog_device), option, facility);
 	RETURN_TRUE;
 }
 /* }}} */
 
-/* {{{ proto int closelog(void)
+/* {{{ proto bool closelog(void)
    Close connection to system logger */
 PHP_FUNCTION(closelog)
 {
+	if (ZEND_NUM_ARGS() != 0) {
+		php_error_docref(NULL TSRMLS_CC, E_WARNING, "expects no parameters, %d given", ZEND_NUM_ARGS());
+		return;
+	}
+
 	closelog();
 	if (BG(syslog_device)) {
 		efree(BG(syslog_device));
@@ -236,24 +249,25 @@ PHP_FUNCTION(closelog)
 }
 /* }}} */
 
-/* {{{ proto int syslog(int priority, string message)
+/* {{{ proto bool syslog(int priority, string message)
    Generate a system log message */
 PHP_FUNCTION(syslog)
 {
-	pval **priority, **message;
+	long priority;
+	char *message;
+	int message_len;
 
-	if (ZEND_NUM_ARGS() != 2 || zend_get_parameters_ex(2, &priority, &message) == FAILURE) {
-		WRONG_PARAM_COUNT;
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "ls", &priority,
+							  &message, &message_len) == FAILURE) {
+		return;
 	}
-	convert_to_long_ex(priority);
-	convert_to_string_ex(message);
 
 	/*
 	 * CAVEAT: if the message contains patterns such as "%s",
 	 * this will cause problems.
 	 */
 
-	php_syslog((*priority)->value.lval, "%.500s", (*message)->value.str.val);
+	php_syslog(priority, "%.500s", message);
 	RETURN_TRUE;
 }
 /* }}} */
@@ -265,6 +279,6 @@ PHP_FUNCTION(syslog)
  * tab-width: 4
  * c-basic-offset: 4
  * End:
- * vim600: sw=4 ts=4 tw=78 fdm=marker
- * vim<600: sw=4 ts=4 tw=78
+ * vim600: sw=4 ts=4 fdm=marker
+ * vim<600: sw=4 ts=4
  */
