@@ -1,13 +1,13 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP version 4.0                                                      |
+   | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2001 The PHP Group                                |
+   | Copyright (c) 1997-2008 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
@@ -17,7 +17,7 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: php_xml.h,v 1.18 2001/07/28 11:36:24 zeev Exp $ */
+/* $Id: php_xml.h,v 1.19.8.2.2.3 2007/12/31 07:22:54 sebastian Exp $ */
 
 #ifndef PHP_XML_H
 #define PHP_XML_H
@@ -79,6 +79,7 @@ typedef struct {
 	char **ltags;
 	int lastwasopen;
 	int skipwhite;
+	int isparsing;
 	
 	XML_Char *baseURI;
 } xml_parser;
