@@ -2,12 +2,12 @@
    +----------------------------------------------------------------------+
    | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2003 The PHP Group                                |
+   | Copyright (c) 1997-2008 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
@@ -16,7 +16,7 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id: zip.c,v 1.33.2.2 2003/03/07 13:42:21 ddhill Exp $ */
+/* $Id: zip.c,v 1.33.2.3.2.4 2007/12/31 07:22:54 sebastian Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -29,7 +29,12 @@
 #if HAVE_ZZIPLIB
 
 #include "ext/standard/info.h"
+
+#ifdef HAVE_NEW_ZZIPLIB
+#include <zzip/zzip.h>
+#else
 #include <zziplib.h>
+#endif
 
 #ifndef O_BINARY
 #define O_BINARY 0
@@ -278,7 +283,7 @@ PHP_FUNCTION(zip_entry_open)
 }
 /* }}} */
 
-/* {{{ proto string zip_entry_read(resource zip_ent)
+/* {{{ proto string zip_entry_read(resource zip_ent [, int nbytes])
    Read X bytes from an opened zip entry */
 PHP_FUNCTION(zip_entry_read)
 {
@@ -291,6 +296,10 @@ PHP_FUNCTION(zip_entry_read)
 	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "r|l", &zzip_ent, &len) == FAILURE) {
 		return;
 	}
+	if (len <= 0) {
+		php_error_docref(NULL TSRMLS_CC, E_WARNING, "The bytes parameter must greater then zero");
+		RETURN_FALSE;
+	}
 	ZEND_FETCH_RESOURCE(entry, php_zzip_dirent *, &zzip_ent, -1, le_zip_entry_name, le_zip_entry);
 
 	buf = emalloc(len + 1);
