@@ -1,34 +1,32 @@
 /* 
    +----------------------------------------------------------------------+
-   | PHP version 4.0                                                      |
+   | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2001 The PHP Group                                |
+   | Copyright (c) 1997-2008 The PHP Group                                |
    +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
-   | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | available through the world-wide-web at the following url:           |
+   | http://www.php.net/license/3_01.txt                                  |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
    +----------------------------------------------------------------------+
-   | Authors: Jaakko Hyvtti <jaakko.hyvatti@iki.fi>                      |
+   | Author: Jaakko Hyvtti <jaakko.hyvatti@iki.fi>                       |
    +----------------------------------------------------------------------+
  */
 
-/* $Id: php_sprintf.c,v 1.9 2001/06/06 13:05:53 rasmus Exp $ */
+/* $Id: php_sprintf.c,v 1.12.8.5.2.3 2007/12/31 07:22:54 sebastian Exp $ */
 
 #include <stdio.h>
 #include <stdarg.h>
-#include "php_config.h"
+#include "php.h"
 
-#if PHP_BROKEN_SPRINTF
-
-int
+PHPAPI int
 php_sprintf (char*s, const char* format, ...)
 {
   va_list args;
-  char *ret;
+  int ret;
 
   va_start (args, format);
   s[0] = '\0';
@@ -39,13 +37,11 @@ php_sprintf (char*s, const char* format, ...)
   return strlen (s);
 }
 
-#endif /* BROKEN_SPRINTF */
-
 /*
  * Local variables:
  * tab-width: 4
  * c-basic-offset: 4
  * End:
- * vim600: sw=4 ts=4 tw=78 fdm=marker
- * vim<600: sw=4 ts=4 tw=78
+ * vim600: sw=4 ts=4 fdm=marker
+ * vim<600: sw=4 ts=4
  */
