@@ -17,7 +17,7 @@
  *
  */
 
-/* $Id: sendmail.c,v 1.47.2.10.2.1 2005/07/28 10:10:16 hyanantha Exp $ */
+/* $Id: sendmail.c,v 1.47.2.10.2.4 2007/01/16 00:11:53 iliaa Exp $ */
 
 #include "php.h"				/*php specific */
 #include <stdio.h>
@@ -42,10 +42,6 @@
 
 #include "ext/standard/php_string.h"
 
-/*
-   extern int _daylight;
-   extern long _timezone;
- */
 /*enum
    {
    DO_CONNECT = WM_USER +1
@@ -96,9 +92,6 @@ char *php_mailer = "PHP 4 WIN32";
 char *php_mailer = "PHP 4 NetWare";
 #endif  /* NETWARE */
 
-
-char *get_header(char *h, char *headers);
-
 /* Error messages */
 static char *ErrorMessages[] =
 {
@@ -215,7 +208,7 @@ static char *php_win32_mail_trim_header(char *header TSRMLS_DC)
 //
 //  See SendText() for additional args!
 //********************************************************************/
-int TSendMail(char *host, int *error, char **error_message,
+PHPAPI int TSendMail(char *host, int *error, char **error_message,
 			  char *headers, char *Subject, char *mailTo, char *data,
 			  char *mailCc, char *mailBcc, char *mailRPath)
 {
@@ -229,7 +222,6 @@ int TSendMail(char *host, int *error, char **error_message,
 	WinsockStarted = FALSE;
 #endif
 
-
 	if (host == NULL) {
 		*error = BAD_MAIL_HOST;
 		return FAILURE;
@@ -309,7 +301,7 @@ int TSendMail(char *host, int *error, char **error_message,
 			MailHost, !INI_INT("smtp_port") ? 25 : INI_INT("smtp_port"));
 		return FAILURE;
 	} else {
-		ret = SendText(RPath, Subject, mailTo, mailCc, mailBcc, data, headers, headers_lc, error_message);
+		ret = SendText(RPath, Subject, mailTo, mailCc, mailBcc, data, headers, headers_lc, error_message TSRMLS_CC);
 		TSMClose();
 		if (RPath) {
 			efree(RPath);
@@ -334,7 +326,7 @@ int TSendMail(char *host, int *error, char **error_message,
 // Author/Date:  jcar 20/9/96
 // History:
 //********************************************************************/
-void TSMClose()
+PHPAPI void TSMClose()
 {
 	Post("QUIT\r\n");
 	Ack(NULL);
@@ -356,7 +348,7 @@ void TSMClose()
 // Author/Date:  jcar 20/9/96
 // History:
 //*******************************************************************/
-char *GetSMErrorText(int index)
+PHPAPI char *GetSMErrorText(int index)
 {
 	if (MIN_ERROR_INDEX <= index && index < MAX_ERROR_INDEX) {
 		return (ErrorMessages[index]);
@@ -386,8 +378,8 @@ char *GetSMErrorText(int index)
 // Author/Date:  jcar 20/9/96
 // History:
 //*******************************************************************/
-int SendText(char *RPath, char *Subject, char *mailTo, char *mailCc, char *mailBcc, char *data, 
-			 char *headers, char *headers_lc, char **error_message)
+static int SendText(char *RPath, char *Subject, char *mailTo, char *mailCc, char *mailBcc, char *data, 
+			 char *headers, char *headers_lc, char **error_message TSRMLS_DC)
 {
 	int res;
 	char *p;
@@ -494,7 +486,7 @@ int SendText(char *RPath, char *Subject, char *mailTo, char *mailCc, char *mailB
 		while(token != NULL)
 		{
 			SMTP_SKIP_SPACE(token);
-			sprintf(Buffer, "RCPT TO:<%s>\r\n", token);
+			snprintf(Buffer, MAIL_BUFFER_SIZE, "RCPT TO:<%s>\r\n", token);
 			if ((res = Post(Buffer)) != SUCCESS)
 				return (res);
 			if ((res = Ack(&server_response)) != SUCCESS) {
@@ -550,7 +542,7 @@ int SendText(char *RPath, char *Subject, char *mailTo, char *mailCc, char *mailB
 			while(token != NULL)
 			{
 				SMTP_SKIP_SPACE(token);
-				sprintf(Buffer, "RCPT TO:<%s>\r\n", token);
+				snprintf(Buffer, MAIL_BUFFER_SIZE, "RCPT TO:<%s>\r\n", token);
 				if ((res = Post(Buffer)) != SUCCESS) {
 					return (res);
 				}
@@ -607,9 +599,9 @@ int SendText(char *RPath, char *Subject, char *mailTo, char *mailCc, char *mailB
 
 	/* send message header */
 	if (Subject == NULL) {
-		res = PostHeader(RPath, "No Subject", mailTo, stripped_header);
+		res = PostHeader(RPath, "No Subject", mailTo, stripped_header TSRMLS_CC);
 	} else {
-		res = PostHeader(RPath, Subject, mailTo, stripped_header);
+		res = PostHeader(RPath, Subject, mailTo, stripped_header TSRMLS_CC);
 	}
 	if (stripped_header) {
 		efree(stripped_header);
@@ -663,7 +655,8 @@ int SendText(char *RPath, char *Subject, char *mailTo, char *mailCc, char *mailB
 	return (SUCCESS);
 }
 
-int addToHeader(char **header_buffer, const char *specifier, char *string) {
+static int addToHeader(char **header_buffer, const char *specifier, char *string)
+{
 	if (NULL == (*header_buffer = erealloc(*header_buffer, strlen(*header_buffer) + strlen(specifier) + strlen(string) + 1))) {
 		return 0;
 	}
@@ -682,7 +675,7 @@ int addToHeader(char **header_buffer, const char *specifier, char *string) {
 // Author/Date:  jcar 20/9/96
 // History:
 //********************************************************************/
-int PostHeader(char *RPath, char *Subject, char *mailTo, char *xheaders)
+static int PostHeader(char *RPath, char *Subject, char *mailTo, char *xheaders TSRMLS_DC)
 {
 
 	/* Print message header according to RFC 822 */
@@ -713,7 +706,7 @@ int PostHeader(char *RPath, char *Subject, char *mailTo, char *xheaders)
 	zonem = (abs(_timezone) / 60) - (zoneh * 60);
 
 	if(!xheaders || !strstr(headers_lc, "date:")){
-		sprintf(header_buffer, "Date: %s, %02d %s %04d %02d:%02d:%02d %s%02d%02d\r\n",
+		sprintf(header_buffer, "Date: %3s, %02d %3s %04d %02d:%02d:%02d %c%02d%02d\r\n",
 					 days[tm->tm_wday],
 					 tm->tm_mday,
 					 months[tm->tm_mon],
@@ -779,7 +772,7 @@ PostHeader_outofmem:
 // Author/Date:  jcar 20/9/96
 // History:
 //********************************************************************/
-int MailConnect()
+static int MailConnect()
 {
 
 	int res;
@@ -820,10 +813,6 @@ int MailConnect()
 }
 
 
-
-
-
-
 /*********************************************************************
 // Name:  Post
 // Input:
@@ -832,7 +821,7 @@ int MailConnect()
 // Author/Date:  jcar 20/9/96
 // History:
 //********************************************************************/
-int Post(LPCSTR msg)
+static int Post(LPCSTR msg)
 {
 	int len = strlen(msg);
 	int slen;
@@ -859,7 +848,7 @@ int Post(LPCSTR msg)
 // Author/Date:  jcar 20/9/96
 // History:
 //********************************************************************/
-int Ack(char **server_response)
+static int Ack(char **server_response)
 {
 	static char buf[MAIL_BUFFER_SIZE];
 	int rlen;
@@ -919,7 +908,7 @@ int Ack(char **server_response)
 // Author/Date:  jcar 20/9/96
 // History:
 //********************************************************************/
-unsigned long GetAddr(LPSTR szHost)
+static unsigned long GetAddr(LPSTR szHost)
 {
 	LPHOSTENT lpstHost;
 	u_long lAddr = INADDR_ANY;
